==> shaddock-0.6.0.dev441.tar.gz: shaddock-0.6.0.dev441/shaddock/scheduler.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2014 Thibaut Lapierre <root@epheo.eu>. All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from operator import itemgetter
from shaddock import checks
from shaddock.drivers.docker.container import Container
from shaddock.drivers.docker.image import Image
from shaddock.model import ModelDefinition
from shaddock.model import TemplateFileError
import time


class Scheduler(object):
    def __init__(self, app_args, name=None):
        self.model = ModelDefinition(app_args.shdk_model, app_args)
        self.services_list = self.model.get_services_list()
        self.name = name
        if name is None:
            try:
                self.services_list.sort(key=itemgetter('priority'))
            except KeyError:
                raise TemplateFileError(
                    "In order to use the scheduler functionality, all the "
                    "services from your model needs to have the priority "
                    "argument defined. At least one of your services does "
                    "not have this argument set.")
            self.checker = checks.Checks(app_args)

    def build(self):
        if self.name is None:
            for svc in self.services_list:
                svc_cfg = self.model.get_service(svc['name'])
                image = Image(svc['name'], svc_cfg)
                image.build()
        else:
            svc_cfg = self.model.get_service(svc['name'])
            image = Image(self.name, svc_cfg)
            image.build()

    def create(self):
        if self.name is None:
            for svc in self.services_list:
                svc_cfg = self.model.get_service(svc['name'])
                container = Container(svc['name'], svc_cfg)
                try:
                    container.create()
                except Exception:
                    pass
        else:
            svc_cfg = self.model.get_service(self.name)
            container = Container(self.name, svc_cfg)
            container.create()

    def start(self):
        if self.name is None:
            for svc in self.services_list:
                svc_cfg = self.model.get_service(svc['name'])
                container = Container(svc['name'], svc_cfg)
                checks = svc.get('depends-on', [])
                if len(checks) > 0:
                    print("Running checks before "
                          "starting: {}".format(svc['name']))
                    for check in checks:
                        self.do_check(check)
                container.start()
        else:
            container = Container(self.name,
                                  self.model.get_service(self.name))
            container.start()

    def remove(self):
        if self.name is None:
            for svc in reversed(self.services_list):
                svc_cfg = self.model.get_service(svc['name'])
                container = Container(svc['name'], svc_cfg)
                container.remove()
        else:
            svc_cfg = self.model.get_service(self.name)
            container = Container(self.name, svc_cfg)
            container.remove()

    def pull(self):
        if self.name is None:
            for svc in self.services_list:
                svc_cfg = self.model.get_service(svc['name'])
                image = Image(svc['name'], svc_cfg)
                image.pull()
        else:
            svc_cfg = self.model.get_service(svc['name'])
            image = Image(self.name, svc_cfg)
            image.pull()

    def stop(self):
        if self.name is None:
            for svc in reversed(self.services_list):
                self.model.get_service(svc['name'])
                container = Container(svc['name'],
                                      self.model.get_service(svc['name']))
                container.stop()
        else:
            container = Container(self.name,
                                  self.model.get_service(self.name))
            container.stop()

    def restart(self):
        self.stop()
        self.start()

    def do_check(self, check, retry=None):
        if retry is None:
            retry = check.get('retry', 15)
        elif retry == 0:
            raise CheckError("The following check ran it's maximum amount of"
                             " retry and is still returning "
                             " False:".format(str(check)))
        print("Running check: {}".format(str(check)))
        if self.checker.run(check):
            pass
        else:
            retry -= 1
            time.sleep(check.get('sleep', 10))
            self.do_check(check, retry)


class CheckError(Exception):
        pass

==> shaddock-0.6.2.dev4.tar.gz: shaddock-0.6.2.dev4/shaddock/scheduler.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2014 Thibaut Lapierre <root@epheo.eu>. All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from operator import itemgetter
from shaddock.checks import Checks
from shaddock.drivers.docker.container import Container
from shaddock.drivers.docker.image import Image
from shaddock.model import ModelDefinition
from shaddock.model import TemplateFileError
import time


class Scheduler(object):
    def __init__(self, app_args, name=None):
        self.model = ModelDefinition(app_args.shdk_model, app_args)
        self.services_list = self.model.get_services_list()
        self.name = name
        if name is None:
            try:
                self.services_list.sort(key=itemgetter('priority'))
            except KeyError:
                raise TemplateFileError(
                    "In order to use the scheduler functionality, all the "
                    "services from your model needs to have the priority "
                    "argument defined. At least one of your services does "
                    "not have this argument set.")
            self.checker = Checks(self.model)

    def build(self):
        if self.name is None:
            for svc in self.services_list:
                image = Image(self.model.build_service_dict(svc))
                image.build()
        else:
            image = Image(self.model.get_service(self.name))
            image.build()

    def create(self):
        if self.name is None:
            for svc in self.services_list:
                container = Container(self.model.build_service_dict(svc))
                try:
                    container.create()
                except Exception:
                    pass
        else:
            container = Container(self.model.get_service(self.name))
            container.create()

    def start(self):
        if self.name is None:
            for svc in self.services_list:
                container = Container(self.model.build_service_dict(svc))
                checks = svc.get('depends-on', [])
                if len(checks) > 0:
                    print("Running checks before "
                          "starting: {}".format(svc['name']))
                    for check in checks:
                        self.do_check(check)
                container.start()
        else:
            container = Container(self.model.get_service(self.name))
            container.start()

    def remove(self):
        if self.name is None:
            for svc in reversed(self.services_list):
                container = Container(self.model.build_service_dict(svc))
                container.remove()
        else:
            container = Container(self.model.get_service(self.name))
            container.remove()

    def pull(self):
        if self.name is None:
            for svc in self.services_list:
                image = Image(self.model.build_service_dict(svc))
                image.pull()
        else:
            image = Image(self.model.get_service(self.name))
            image.pull()

    def stop(self):
        if self.name is None:
            for svc in reversed(self.services_list):
                container = Container(self.model.build_service_dict(svc))
                container.stop()
        else:
            container = Container(self.model.get_service(self.name))
            container.stop()

    def restart(self):
        self.stop()
        self.start()

    def do_check(self, check, retry=None):
        if retry is None:
            retry = check.get('retry', 15)
        elif retry == 0:
            raise CheckError("The following check ran it's maximum amount of"
                             " retry and is still returning "
                             " False:".format(str(check)))
        print("Running check: {}".format(str(check)))
        if self.checker.run(check):
            pass
        else:
            retry -= 1
            time.sleep(check.get('sleep', 10))
            self.do_check(check, retry)


class CheckError(Exception):
        pass
